@@ -36,6 +36,8 @@
 
 #include <vector>
 
+#include "G4Types.hh"
+
 #ifdef G4MULTITHREADED
 #include "G4MTRunManager.hh"
 #else
@@ -59,14 +61,14 @@
 #include "G4GDMLParser.hh"
 
 void print_aux(const G4GDMLAuxListType* auxInfoList, G4String prepend="|")
-{  
+{
   for(std::vector<G4GDMLAuxStructType>::const_iterator
       iaux = auxInfoList->begin(); iaux != auxInfoList->end(); iaux++ )
     {
       G4String str=iaux->type;
       G4String val=iaux->value;
       G4String unit=iaux->unit;
-      
+
       G4cout << prepend << str << " : " << val  << " " << unit << G4endl;
 
       if (iaux->auxList) print_aux(iaux->auxList, prepend + "|");
@@ -95,8 +97,9 @@ int main(int argc,char **argv)
 // Uncomment the following if wish to avoid names stripping
 // parser.SetStripFlag(false);
 
+   parser.SetOverlapCheck(true);
    parser.Read(argv[1]);
-   
+
    if (argc>4)
    {
       G4cout << "Error! Too many arguments!" << G4endl;
@@ -123,14 +126,14 @@ int main(int argc,char **argv)
 
    // Get the pointer to the User Interface manager
    G4UImanager* UImanager = G4UImanager::GetUIpointer();
- 
+
    ///////////////////////////////////////////////////////////////////////
    //
    // Example how to retrieve Auxiliary Information
    //
 
    G4cout << std::endl;
-   
+
    const G4LogicalVolumeStore* lvs = G4LogicalVolumeStore::GetInstance();
    std::vector<G4LogicalVolume*>::const_iterator lvciter;
    for( lvciter = lvs->begin(); lvciter != lvs->end(); lvciter++ )
@@ -140,7 +143,7 @@ int main(int argc,char **argv)
      if (auxInfo.size()>0)
        G4cout << "Auxiliary Information is found for Logical Volume :  "
               << (*lvciter)->GetName() << G4endl;
-     
+
      print_aux(&auxInfo);
    }
 
@@ -149,44 +152,49 @@ int main(int argc,char **argv)
    G4cout << "Global auxiliary info:" << std::endl;
    G4cout << std::endl;
 
-   print_aux(parser.GetAuxList());   
+   print_aux(parser.GetAuxList());
 
    G4cout << std::endl;
-   
+
    //
    // End of Auxiliary Information block
    //
    ////////////////////////////////////////////////////////////////////////
 
-   // example of writing out
+
+   runManager->BeamOn(0);
    
+   // example of writing out
+
    if (argc>=3)
    {
 /*
      G4GDMLAuxStructType mysubaux = {"mysubtype", "mysubvalue", "mysubunit", 0};
      G4GDMLAuxListType* myauxlist = new G4GDMLAuxListType();
      myauxlist->push_back(mysubaux);
-     
+
      G4GDMLAuxStructType myaux = {"mytype", "myvalue", "myunit", myauxlist};
      parser.AddAuxiliary(myaux);
 
 
      // example of setting auxiliary info for world volume
      // (can be set for any volume)
-     
+
      G4GDMLAuxStructType mylocalaux = {"sometype", "somevalue", "someunit", 0};
 
      parser.AddVolumeAuxiliary(mylocalaux,
        G4TransportationManager::GetTransportationManager()
        ->GetNavigatorForTracking()->GetWorldVolume()->GetLogicalVolume());
 */
+
      parser.SetRegionExport(true);
+     //     parser.SetEnergyCutsExport(true);
      parser.Write(argv[2], G4TransportationManager::GetTransportationManager()
       ->GetNavigatorForTracking()->GetWorldVolume()->GetLogicalVolume());
    }
-   
 
-   if (argc==4)   // batch mode  
+
+   if (argc==4)   // batch mode
    {
      G4String command = "/control/execute ";
      G4String fileName = argv[3];
